import json
import requests

def get_headers():
    return {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
    }

def ensure_json(data):
    # Check if the data is already a JSON string
    if isinstance(data, str):
        try:
            json.loads(data)  # Verify it's valid JSON
            return data
        except ValueError:
            pass  # Not valid JSON, continue to dump it
    # If it's not a string, or not valid JSON, dump it
    return json.dumps(data)

def getPostRequest(url, data, headers=None):
    if headers is None:
        headers = get_headers()
    data = ensure_json(data)
    response = requests.post(url, data=data, headers=headers)
    return response.json()

def getGetRequest(url, data, headers=None):
    if headers is None:
        headers = get_headers()
    data = ensure_json(data)
    response = requests.get(url, data=data, headers=headers)
    return response.json()



from time import time
import setuptools
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setuptools.setup(
    name='abstract_apis',
    version='0.0.0.1',
    author='putkoff',
    author_email='partners@abstractendeavors.com',
    description="`abstract_apis` is a Python module designed to simplify HTTP requests by abstracting common request setups and processing. It helps developers make GET and POST requests with JSON content easily, managing headers and data serialization internally.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.11',
      ],
    install_requires=['abstract_utilities','requests'],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    # Add this line to include wheel format in your distribution
    setup_requires=['wheel'],
)
